==> qmmp-1.3.4-1.src.tar.gz: qmmp-1.3.4/src/plugins/Effect/bs2b/translations/bs2b_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>EffectBs2bFactory</name>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="31"/>
        <source>BS2B Plugin</source>
        <translation>BS2B 外掛</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="51"/>
        <source>About BS2B Effect Plugin</source>
        <translation>關於BS2B 特效插件</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="52"/>
        <source>This is the Qmmp plugin version of Boris Mikhaylov&apos;s headphone DSP effect &quot;Bauer stereophonic-to-binaural&quot;, abbreviated bs2b.</source>
        <translation>此版本的 Qmmp 插件基於 Boris Mikhaylov 的耳機 DSP 特效 &quot;Bauer stereophonic-to-binaural&quot;, 簡單的 bs2b.</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="54"/>
        <source>Visit %1 for more details</source>
        <translation>訪問 %1 了解更多內容</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="56"/>
        <source>Compiled against libbs2b-%1</source>
        <translation>編譯依賴 libbs2b-%1</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="57"/>
        <source>Developers:</source>
        <translation>開發者：</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="58"/>
        <source>Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="59"/>
        <source>Sebastian Pipping &amp;lt;sebastian@pipping.org&amp;gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>BS2B Plugin Settings</source>
        <translation>BS2B 插件設置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="32"/>
        <source>Crossfeed level</source>
        <translation>串擾水平</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <location filename="../settingsdialog.ui" line="59"/>
        <source>-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Default</source>
        <translation>預設</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>C.Moy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="85"/>
        <source>J. Meier</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="60"/>
        <source>%1 Hz, %2 us</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="67"/>
        <source>%1 dB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp-2.2.4-1.src.tar.gz: qmmp-2.2.4/src/plugins/Effect/bs2b/translations/bs2b_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>Bs2bSettingsDialog</name>
    <message>
        <location filename="../bs2bsettingsdialog.ui" line="14"/>
        <source>BS2B Plugin Settings</source>
        <translation>BS2B 插件設置</translation>
    </message>
    <message>
        <location filename="../bs2bsettingsdialog.ui" line="32"/>
        <source>Crossfeed level</source>
        <translation>串擾水平</translation>
    </message>
    <message>
        <location filename="../bs2bsettingsdialog.ui" line="45"/>
        <location filename="../bs2bsettingsdialog.ui" line="59"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../bs2bsettingsdialog.ui" line="71"/>
        <source>Default</source>
        <translation>默認</translation>
    </message>
    <message>
        <location filename="../bs2bsettingsdialog.ui" line="78"/>
        <source>C.Moy</source>
        <translation>C.Moy</translation>
    </message>
    <message>
        <location filename="../bs2bsettingsdialog.ui" line="85"/>
        <source>J. Meier</source>
        <translation>J. Meier</translation>
    </message>
    <message>
        <location filename="../bs2bsettingsdialog.cpp" line="61"/>
        <source>%1 Hz, %2 us</source>
        <translation>%1 Hz, %2 us</translation>
    </message>
    <message>
        <location filename="../bs2bsettingsdialog.cpp" line="68"/>
        <source>%1 dB</source>
        <translation>%1 dB</translation>
    </message>
</context>
<context>
    <name>EffectBs2bFactory</name>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="31"/>
        <source>BS2B Plugin</source>
        <translation>BS2B 外掛</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="50"/>
        <source>About BS2B Effect Plugin</source>
        <translation>關於BS2B 特效插件</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="52"/>
        <source>This is the Qmmp plugin version of Boris Mikhaylov&apos;s headphone DSP effect &quot;Bauer stereophonic-to-binaural&quot;, abbreviated bs2b.</source>
        <translation>此版本的 Qmmp 插件基於 Boris Mikhaylov 的耳機 DSP 特效 &quot;Bauer stereophonic-to-binaural&quot;, 簡單的 bs2b.</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="55"/>
        <source>Visit %1 for more details</source>
        <translation>訪問 %1 了解更多內容</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="57"/>
        <source>Compiled against libbs2b-%1</source>
        <translation>編譯依賴 libbs2b-%1</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="59"/>
        <source>Developers:</source>
        <translation>開發者：</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="60"/>
        <source>Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</source>
        <translation>Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</translation>
    </message>
    <message>
        <location filename="../effectbs2bfactory.cpp" line="61"/>
        <source>Sebastian Pipping &amp;lt;sebastian@pipping.org&amp;gt;</source>
        <translation>Sebastian Pipping &amp;lt;sebastian@pipping.org&amp;gt;</translation>
    </message>
</context>
</TS>
